Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/tests.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/tests.py	(revision 15730)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/tests.py	(revision 15755)
@@ -44,4 +44,5 @@
 API_KEY = '1946'
 SERVICETYPEID = '4430731'
+GATEWAY_AMT = 0.0
 
 def external_test(func):
@@ -86,4 +87,7 @@
                 lineitems=self.lineitems)
         return resp
+
+    def test_dummytest(self):
+        return
 
     @external_test

Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/applicantsbrowser.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/applicantsbrowser.py	(revision 15730)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/applicantsbrowser.py	(revision 15755)
@@ -34,5 +34,5 @@
 
 from kofacustom.nigeria.remita.tests import (
     MERCHANTID, HOST, HTTPS, API_KEY, SERVICETYPEID)
 
 grok.templatedir('browser_templates')
@@ -235,4 +235,6 @@
         if self.context.p_state == 'paid':
             return _("Payment ticket can't be re-sent to Remita.")
+        if self.context.r_company and self.context.r_company != 'remita':
+            return _("Payment ticket has been used for another payment gateway.")
         now = datetime.utcnow()
         if self.context.creation_date.tzinfo is not None:
@@ -260,6 +262,4 @@
         if resp.get('statuscode') not in ('021', '025', '055'):
             return 'RRR generation message from Remita: ' + resp.get('status')
-        # Already now it becomes a Remita payment
-        self.context.r_company = u'remita'
         self.rrr = self.context.r_pay_reference = resp['RRR'].rstrip()
         hashargs = 	self.merchantId + self.rrr + self.api_key
@@ -269,5 +269,4 @@
             'RRR retrieved: %s, ServiceTypeId: %s'
             % (self.rrr, self.serviceTypeId))
-
         return
 
@@ -281,3 +280,11 @@
             self.redirect(self.url(self.context, '@@index'))
             return
-        return
+        # Already now it becomes a Remita payment. We set the net amount
+        # and add the gateway amount.
+        if not self.context.r_company:
+            self.context.net_amt = self.context.amount_auth
+            self.context.amount_auth += self.gateway_amt
+            self.context.gateway_amt = self.gateway_amt
+            self.context.r_company = u'remita'
+        self.amount_auth = int(100 * self.context.amount_auth)
+        return
@@ -34,5 +34,5 @@
 
 from kofacustom.nigeria.remita.tests import (
-    MERCHANTID, HOST, HTTPS, API_KEY, SERVICETYPEID)
+    MERCHANTID, HOST, HTTPS, API_KEY, SERVICETYPEID, GATEWAY_AMT)
 
 grok.templatedir('browser_templates')
Index: main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/studentsbrowser.py
===================================================================
--- main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/studentsbrowser.py	(revision 15730)
+++ main/kofacustom.nigeria/trunk/src/kofacustom/nigeria/remita/studentsbrowser.py	(revision 15755)
@@ -34,5 +34,5 @@
 
 from kofacustom.nigeria.remita.tests import (
     MERCHANTID, HOST, HTTPS, API_KEY, SERVICETYPEID)
 
 grok.templatedir('browser_templates')
@@ -221,4 +221,5 @@
     api_key = API_KEY
     serviceTypeId = SERVICETYPEID
+    gateway_amt = GATEWAY_AMT
 
     #orderId = '3456346346'
@@ -243,4 +244,6 @@
         if self.context.p_state == 'paid':
             return _("Payment ticket can't be re-sent to Remita.")
+        if self.context.r_company and self.context.r_company != 'remita':
+            return _("Payment ticket has been used for another payment gateway.")
         now = datetime.utcnow()
         if self.context.creation_date.tzinfo is not None:
@@ -276,6 +279,4 @@
         if resp.get('statuscode') not in ('021', '025', '055'):
             return 'RRR generation message from Remita: ' + resp.get('status')
-        # Already now it becomes a Remita payment
-        self.context.r_company = u'remita'
         self.rrr = self.context.r_pay_reference = resp['RRR'].rstrip()
         hashargs = 	self.merchantId + self.rrr + self.api_key
@@ -296,3 +297,11 @@
             self.redirect(self.url(self.context, '@@index'))
             return
-        return
+        # Already now it becomes a Remita payment. We set the net amount
+        # and add the gateway amount.
+        if not self.context.r_company:
+            self.context.net_amt = self.context.amount_auth
+            self.context.amount_auth += self.gateway_amt
+            self.context.gateway_amt = self.gateway_amt
+            self.context.r_company = u'remita'
+        self.amount_auth = int(100 * self.context.amount_auth)
+        return
@@ -34,5 +34,5 @@
 
 from kofacustom.nigeria.remita.tests import (
-    MERCHANTID, HOST, HTTPS, API_KEY, SERVICETYPEID)
+    MERCHANTID, HOST, HTTPS, API_KEY, SERVICETYPEID, GATEWAY_AMT)
 
 grok.templatedir('browser_templates')